@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class ModelCloneConfig(AppConfig):
-    name = 'model_clone'
+    name = "model_clone"
